@@ -26,7 +26,7 @@
 
 #include <QDebug>
 
-#include "grantlee_core.h"
+#include "grantlee_templates.h"
 #include "grantlee_paths.h"
 
 #include "designwidget.h"
@@ -80,6 +80,7 @@ MainWindow::MainWindow(QWidget* parent, Qt::WindowFlags flags)
   m_engine = new Grantlee::Engine(this);
   m_engine->setPluginPaths( QStringList() << GRANTLEE_PLUGIN_PATH << ":/plugins" );
   m_engine->addDefaultLibrary( "grantlee_scriptabletags" );
+  m_engine->setSmartTrimEnabled(true);
 
   m_loader = Grantlee::FileSystemTemplateLoader::Ptr( new Grantlee::FileSystemTemplateLoader );
   m_loader->setTemplateDirs( QStringList() << ":/templates" );
