@@ -129,6 +129,18 @@ void Engine::removeDefaultLibrary( const QString &libName )
   d->m_defaultLibraries.removeAll( libName );
 }
 
+template<uint v>
+bool acceptableVersion(uint minorVersion)
+{
+  return minorVersion >= v;
+}
+
+template<>
+bool acceptableVersion<0>(uint)
+{
+  return true;
+}
+
 void Engine::loadDefaultLibraries()
 {
   Q_D( Engine );
@@ -168,7 +180,7 @@ void Engine::loadDefaultLibraries()
     // The C++ plugins are different because although they are loaded, their NodeFactories
     // and Filters are accessed only by the Parser, which manages them after that.
     uint minorVersion = GRANTLEE_VERSION_MINOR;
-    while ( minorVersion >= GRANTLEE_MIN_PLUGIN_VERSION ) {
+    while ( acceptableVersion<GRANTLEE_MIN_PLUGIN_VERSION>(minorVersion) ) {
       // Although we don't use scripted libaries here, we need to recognize them being first
       // in the search path and not load a c++ plugin of the same name in that case.
       ScriptableLibraryContainer* scriptableLibrary = d->loadScriptableLibrary( libName, minorVersion );
@@ -177,7 +189,10 @@ void Engine::loadDefaultLibraries()
         break;
       }
 
-      PluginPointer<TagLibraryInterface> library = d->loadCppLibrary( libName, minorVersion-- );
+      PluginPointer<TagLibraryInterface> library = d->loadCppLibrary( libName, minorVersion );
+      if ( minorVersion == 0)
+        break;
+      minorVersion--;
       if ( library )
         break;
     }
@@ -196,10 +211,13 @@ TagLibraryInterface* Engine::loadLibrary( const QString &name )
     return d->m_libraries.value( name ).data();
 
   uint minorVersion = GRANTLEE_VERSION_MINOR;
-  while ( minorVersion >= GRANTLEE_MIN_PLUGIN_VERSION ) {
-    TagLibraryInterface* library = d->loadLibrary( name, minorVersion-- );
+  while ( acceptableVersion<GRANTLEE_MIN_PLUGIN_VERSION>(minorVersion) ) {
+    TagLibraryInterface* library = d->loadLibrary( name, minorVersion );
     if ( library )
       return library;
+    if (minorVersion == 0)
+      break;
+    minorVersion--;
   }
   throw Grantlee::Exception( TagSyntaxError, QString::fromLatin1( "Plugin library '%1' not found." ).arg( name ) );
   return 0;
@@ -312,9 +330,13 @@ PluginPointer<TagLibraryInterface> EnginePrivate::loadCppLibrary( const QString
     if ( list.isEmpty() )
       continue;
 
-    PluginPointer<TagLibraryInterface> plugin = PluginPointer<TagLibraryInterface>( pluginDir.absoluteFilePath( list.first() ) );
+    QString pluginPath=pluginDir.absoluteFilePath( list.first() );
+    PluginPointer<TagLibraryInterface> plugin = PluginPointer<TagLibraryInterface>( pluginPath );
 
     if ( plugin ) {
+#ifdef __COVERAGESCANNER__
+      __coveragescanner_register_library(pluginPath.toLatin1().data());
+#endif
       m_libraries.insert( name, plugin );
       return plugin;
     }
