@@ -30,6 +30,7 @@
 #include <QtCore/QStringList>
 #include <QtCore/QStack>
 #include <QtCore/QQueue>
+#include <QtCore/QDateTime>
 
 #include <deque>
 #include <list>
@@ -43,6 +44,7 @@ namespace Grantlee
 
 /// @headerfile metatype.h grantlee/metatype.h
 
+#ifndef Q_QDOC
 /**
   @brief The MetaType is the interface to the Grantlee introspection system.
 
@@ -57,7 +59,6 @@ namespace Grantlee
 class GRANTLEE_CORE_EXPORT MetaType
 {
 public:
-#ifndef Q_QDOC
   /**
     @internal The signature for a property lookup method
    */
@@ -107,23 +108,21 @@ public:
     @internal
    */
   static bool toListAlreadyRegistered( int id );
-#endif
 
   /**
     Initializes the MetaType system with built in types and containers.
    */
   static inline int init();
 
-#ifndef Q_QDOC
   /**
     @internal
    */
   static int initBuiltins() { return init(); }
-#endif
 
 private:
   MetaType();
 };
+#endif
 
 namespace
 {
@@ -133,11 +132,53 @@ namespace
  */
 template<typename RealType, typename HandleAs>
 struct LookupTrait
+{
+  static QVariant doLookUp( const QVariant &object, const QString &property );
+};
+
+template<typename T>
+struct IsQObjectStar
+{
+  enum { Yes = false };
+};
+
+template<typename T>
+struct IsQObjectStar<T*>
+{
+  typedef int yes_type;
+  typedef char no_type;
+
+  static yes_type check(QObject*);
+  static no_type check(...);
+  enum { Yes = sizeof(check(static_cast<T*>(0))) == sizeof(yes_type) };
+};
+
+template<typename T, bool>
+struct LookupPointer
 {
   static QVariant doLookUp( const QVariant &object, const QString &property )
   {
-    typedef typename Grantlee::TypeAccessor<HandleAs> Accessor;
-    return Accessor::lookUp( static_cast<HandleAs>( object.value<RealType>() ), property );
+    typedef typename Grantlee::TypeAccessor<T> Accessor;
+    return Accessor::lookUp( object.value<T>(), property );
+  }
+};
+
+template<typename T>
+struct LookupPointer<T, true>
+{
+  static QVariant doLookUp( const QVariant &object, const QString &property )
+  {
+    typedef typename Grantlee::TypeAccessor<QObject*> Accessor;
+    return Accessor::lookUp( object.value<T>(), property );
+  }
+};
+
+template<typename RealType>
+struct LookupTrait<RealType*, RealType*>
+{
+  static QVariant doLookUp( const QVariant &object, const QString &property )
+  {
+    return LookupPointer<RealType*, IsQObjectStar<RealType*>::Yes>::doLookUp(object, property);
   }
 };
 
@@ -333,6 +374,7 @@ Q_GLOBAL_STATIC( BuiltinRegister, builtinRegister )
 
 }
 
+#ifndef Q_QDOC
 struct MetaTypeInitializer {
   static inline int initialize()
   {
@@ -341,14 +383,22 @@ struct MetaTypeInitializer {
       return 0;
   }
 };
+#endif
 
+/**
+  Macro to initialize the metatype system.
+
+  @see @ref generic_types
+ */
 #define GRANTLEE_METATYPE_INITIALIZE static const int i = Grantlee::MetaTypeInitializer::initialize(); Q_UNUSED(i)
 
+#ifndef Q_QDOC
 inline int MetaType::init()
 {
   GRANTLEE_METATYPE_INITIALIZE
   return 0;
 }
+#endif
 
 /**
   @brief Registers the type RealType with the metatype system.
