@@ -25,10 +25,11 @@
 #include "template.h"
 #include "test_macros.h"
 
-#include <QtTest/QtTest>
+#include <QtTest/QTest>
 #include <QtCore/QVariant>
 #include <QtCore/QVariantHash>
 #include <QtCore/QMetaType>
+#include <QtCore/QLinkedList>
 
 #include <string>
 #include "coverageobject.h"
@@ -74,6 +75,9 @@ private Q_SLOTS:
   void testNestedContainers();
 
   void testCustomQObjectDerived();
+
+  void testUnregistered();
+  void testPointerNonQObject();
 }; // class TestGenericTypes
 
 class Person
@@ -245,11 +249,72 @@ void testSequentialIndexing( Grantlee::Context c )
   }
 }
 
-template<>
-void testSequentialIndexing<QLinkedList<QVariant> >( Grantlee::Context )
+template<typename Container>
+struct SequentialContainerTester
 {
-  // No op
-}
+  static void iteration(Grantlee::Context c)
+  {
+    testSequentialIteration<Container>(c);
+  }
+
+  static void indexing(Grantlee::Context c)
+  {
+    testSequentialIndexing<Container>(c);
+  }
+};
+
+template<typename T>
+struct SequentialContainerTester<QSet<T> >
+{
+  static void iteration(Grantlee::Context c)
+  {
+    Grantlee::Engine engine;
+
+    engine.setPluginPaths( QStringList() << QLatin1String( GRANTLEE_PLUGIN_PATH ) );
+
+    Grantlee::Template t1 = engine.newTemplate(
+        QLatin1String( "{% for person in people %}{{ person.name }},{% endfor %}" ),
+        QLatin1String( "people_template" ) );
+    QString result = t1->render( &c );
+    QStringList output;
+    output << QString::fromLatin1("Claire,") << QString::fromLatin1("Grant,") << QString::fromLatin1("Alan,");
+    Q_FOREACH(const QString &s, output) {
+      QVERIFY( result.contains(s) );
+    }
+
+    QCOMPARE(result.length(), output.join(QString()).length());
+  }
+
+  static void indexing(Grantlee::Context)
+  {
+  }
+};
+
+template<typename T>
+struct SequentialContainerTester<QLinkedList<T> >
+{
+  static void iteration(Grantlee::Context c)
+  {
+    testSequentialIteration<QLinkedList<T> >(c);
+  }
+
+  static void indexing(Grantlee::Context)
+  {
+  }
+};
+
+template<typename T>
+struct SequentialContainerTester<std::list<T> >
+{
+  static void iteration(Grantlee::Context c)
+  {
+    testSequentialIteration<std::list<T> >(c);
+  }
+
+  static void indexing(Grantlee::Context)
+  {
+  }
+};
 
 template<typename Container>
 void doTestSequentialContainer_Variant()
@@ -258,8 +323,8 @@ void doTestSequentialContainer_Variant()
 
   insertPeopleVariants<Container>( c );
 
-  testSequentialIteration<Container>( c );
-  testSequentialIndexing<Container>( c );
+  SequentialContainerTester<Container>::iteration( c );
+  SequentialContainerTester<Container>::indexing( c );
 }
 
 template<typename Container>
@@ -401,24 +466,6 @@ void insertAssociatedPeople_Number( Grantlee::Context &c )
   c.insert( QLatin1String( "people" ), QVariant::fromValue( container ) );
 }
 
-template<>
-void testSequentialIndexing<QLinkedList<Person> >( Grantlee::Context )
-{
-  // No op
-}
-
-template<>
-void testSequentialIndexing<QSet<Person> >( Grantlee::Context )
-{
-  // No op
-}
-
-template<>
-void testSequentialIndexing<std::list<Person> >( Grantlee::Context )
-{
-  // No op
-}
-
 template<typename Container>
 void doTestSequentialContainer_Type()
 {
@@ -426,8 +473,8 @@ void doTestSequentialContainer_Type()
 
   insertPeople<Container>( c );
 
-  testSequentialIteration<Container>( c );
-  testSequentialIndexing<Container>( c );
+  SequentialContainerTester<Container>::iteration( c );
+  SequentialContainerTester<Container>::indexing( c );
 }
 
 template<typename Container>
@@ -456,6 +503,15 @@ void doTestAssociativeContainer_Type_Number( bool unordered = false )
   insertAssociatedPeople_Number<Container>( c );
   testAssociativeValues<Container>( c, unordered );
   testAssociativeItems<Container>( c, unordered );
+
+  {
+    Grantlee::Template t1 = engine.newTemplate(
+        QLatin1String( "{{ people.23.name }}" ),
+        QLatin1String( "claire_template" ) );
+    QString result = t1->render( &c );
+    QCOMPARE( result, QLatin1String( "Claire" ) );
+  }
+
 }
 
 void TestGenericTypes::testSequentialContainer_Type()
@@ -704,6 +760,97 @@ void TestGenericTypes::testCustomQObjectDerived()
   }
 }
 
+struct UnregisteredType
+{
+
+};
+
+Q_DECLARE_METATYPE(UnregisteredType)
+
+struct RegisteredNotListType
+{
+
+};
+
+Q_DECLARE_METATYPE(RegisteredNotListType)
+
+GRANTLEE_BEGIN_LOOKUP(RegisteredNotListType)
+  Q_UNUSED( object )
+  if ( property == QLatin1String( "property" ) )
+    return 42;
+GRANTLEE_END_LOOKUP
+
+static QVariantList dummy( const QVariant& )
+{
+  return QVariantList() << 42;
+}
+
+QVariant dummyLookup( const QVariant &, const QString & )
+{
+  return 42;
+}
+
+void TestGenericTypes::testUnregistered()
+{
+
+  {
+    UnregisteredType unregType;
+    QVariant v = QVariant::fromValue( unregType );
+
+    QVariant result = Grantlee::MetaType::lookup( v, QLatin1String( "property" ) );
+    QVERIFY( !result.isValid() );
+
+    QVariantList resultList = Grantlee::MetaType::toVariantList( v );
+    QVERIFY( resultList.isEmpty() );
+  }
+
+  Grantlee::registerMetaType<RegisteredNotListType>();
+
+  {
+    RegisteredNotListType nonListType;
+    QVariant v = QVariant::fromValue( nonListType );
+    QVariant result = Grantlee::MetaType::lookup( v, QLatin1String( "property" ) );
+    QVERIFY( result.isValid() );
+    QVariantList resultList = Grantlee::MetaType::toVariantList( v );
+    QVERIFY( resultList.isEmpty() );
+  }
+
+  {
+    Grantlee::MetaType::registerToVariantListOperator(qMetaTypeId<UnregisteredType>(), dummy);
+    UnregisteredType unregType;
+    QVariant v = QVariant::fromValue( unregType );
+    QVariant result = Grantlee::MetaType::lookup( v, QLatin1String( "property" ) );
+    QVERIFY( !result.isValid() );
+  }
+
+  // Only do this in release mode?
+//   Grantlee::MetaType::registerLookUpOperator(0, dummyLookup);
+//   Grantlee::MetaType::registerToVariantListOperator(0, dummy);
+}
+
+
+Q_DECLARE_METATYPE( Person* )
+
+GRANTLEE_BEGIN_LOOKUP_PTR(Person)
+  if ( property == QLatin1String( "name" ) )
+    return QString::fromStdString( object->name );
+  else if ( property == QLatin1String( "age" ) )
+    return object->age;
+GRANTLEE_END_LOOKUP
+
+void TestGenericTypes::testPointerNonQObject()
+{
+  Person *p = new Person( "Adele", 21 );
+  QVariant v = QVariant::fromValue(p);
+
+  Grantlee::registerMetaType<Person*>();
+
+  QVariant result = Grantlee::MetaType::lookup( v, QLatin1String( "name" ) );
+
+  QCOMPARE( result.toString(), QLatin1String( "Adele" ) );
+
+  delete p;
+}
+
 QTEST_MAIN( TestGenericTypes )
 #include "testgenerictypes.moc"
-
