@@ -25,7 +25,8 @@
 #include "util.h"
 
 #include <QtCore/QScopedPointer>
-#include <QtTest/QtTest>
+#include <QtCore/QTranslator>
+#include <QtTest/QTest>
 #include "coverageobject.h"
 
 using namespace Grantlee;
@@ -71,6 +72,9 @@ public:
   }
 
 private Q_SLOTS:
+  void initTestCase();
+
+  void testContext();
   void testStrings();
   void testIntegers();
   void testFloats();
@@ -102,9 +106,25 @@ private:
   Grantlee::Engine *m_engine;
 };
 
+void TestInternationalization::initTestCase()
+{
+  Q_INIT_RESOURCE(testresource);
+}
+
+void TestInternationalization::testContext()
+{
+  Context c;
+  QVERIFY(c.localizer());
+  c.setLocalizer(cLocalizer);
+  QVERIFY(c.localizer());
+  c.setLocalizer(QSharedPointer<Grantlee::AbstractLocalizer>());
+  QVERIFY(c.localizer());
+}
+
 void TestInternationalization::testStrings()
 {
   QFETCH(QString, input);
+  QFETCH(QString, null_output);
   QFETCH(QString, de_output);
   QFETCH(QString, fr_output);
   QFETCH(QString, disambiguation);
@@ -113,19 +133,23 @@ void TestInternationalization::testStrings()
 
   if (!disambiguation.isEmpty()) {
     if (!plural.isEmpty()) {
+      QCOMPARE(nullLocalizer->localizePluralContextString(input, plural, disambiguation, args), null_output);
       QCOMPARE(deLocalizer->localizePluralContextString(input, plural, disambiguation, args), de_output);
       QCOMPARE(frLocalizer->localizePluralContextString(input, plural, disambiguation, args), fr_output);
       return;
     }
+    QCOMPARE(nullLocalizer->localizeContextString(input, disambiguation, args), null_output);
     QCOMPARE(deLocalizer->localizeContextString(input, disambiguation, args), de_output);
     QCOMPARE(frLocalizer->localizeContextString(input, disambiguation, args), fr_output);
     return;
   }
   if (!plural.isEmpty()) {
+    QCOMPARE(nullLocalizer->localizePluralString(input, plural, args), null_output);
     QCOMPARE(deLocalizer->localizePluralString(input, plural, args), de_output);
     QCOMPARE(frLocalizer->localizePluralString(input, plural, args), fr_output);
     return;
   }
+  QCOMPARE(nullLocalizer->localizeString(input, args), null_output);
   QCOMPARE(deLocalizer->localizeString(input, args), de_output);
   QCOMPARE(frLocalizer->localizeString(input, args), fr_output);
 }
@@ -133,6 +157,7 @@ void TestInternationalization::testStrings()
 void TestInternationalization::testStrings_data()
 {
   QTest::addColumn<QString>("input");
+  QTest::addColumn<QString>("null_output");
   QTest::addColumn<QString>("de_output");
   QTest::addColumn<QString>("fr_output");
   QTest::addColumn<QString>("disambiguation");
@@ -143,6 +168,7 @@ void TestInternationalization::testStrings_data()
   // only to test for example that disambiguation and arg reordering works.
 
   QTest::newRow("string-01") << "Birthday"
+                             << "Birthday"
                              << "Geburtstag"
                              << "Anniversaire"
                              << QString()
@@ -150,6 +176,7 @@ void TestInternationalization::testStrings_data()
                              << QVariantList();
 
   QTest::newRow("string-02") << "%n People"
+                             << "1 People"
                              << "1 Person"
                              << "1 Personne"
                              << QString()
@@ -157,6 +184,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 1);
 
   QTest::newRow("string-03") << "%n People"
+                             << "2 People"
                              << "2 Personen"
                              << "2 Personnes"
                              << QString()
@@ -164,6 +192,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 2);
 
   QTest::newRow("string-04") << "Name"
+                             << "Name"
                              << "Name eines Buches"
                              << "Nom d'un livre"
                              << QString::fromLatin1("Name of a Book")
@@ -171,6 +200,7 @@ void TestInternationalization::testStrings_data()
                              << QVariantList();
 
   QTest::newRow("string-05") << "Name"
+                             << "Name"
                              << "Namen einer Person"
                              << "Nom d'une personne"
                              << QString::fromLatin1("Name of a Person")
@@ -178,6 +208,7 @@ void TestInternationalization::testStrings_data()
                              << QVariantList();
 
   QTest::newRow("string-06") << "%n People"
+                             << "1 People"
                              << "1 Person angemeldet"
                              << QString::fromUtf8("1 Personne connecté")
                              << QString::fromLatin1("%n people are logged in")
@@ -185,6 +216,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 1);
 
   QTest::newRow("string-07") << "%n People"
+                             << "2 People"
                              << "2 Personen angemeldet"
                              << QString::fromUtf8("2 Personnes connecté")
                              << QString::fromLatin1("%n people are logged in")
@@ -192,6 +224,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 2);
 
   QTest::newRow("string-08") << "%n file(s) copied to %1"
+                             << "1 files copied to destinationFolder"
                              << "1 Datei in destinationFolder kopiert"
                              << QString::fromUtf8("1 fichier copié dans destinationFolder")
                              << QString()
@@ -199,6 +232,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 1 << QString::fromLatin1("destinationFolder") );
 
   QTest::newRow("string-09") << "%n file(s) copied to %1"
+                             << "2 files copied to destinationFolder"
                              << "2 Datein in destinationFolder kopiert"
                              << QString::fromUtf8("2 fichiers copiés dans destinationFolder")
                              << QString()
@@ -206,6 +240,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 2 << QString::fromLatin1("destinationFolder") );
 
   QTest::newRow("string-10") << "%n to %1"
+                             << "1 copied to destinationFolder"
                              << "1 Datei wird nach destinationFolder kopiert"
                              << QString::fromUtf8("1 fichier est copié sur destinationFolder")
                              << QString::fromLatin1("Files are being copied")
@@ -213,6 +248,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 1 << QString::fromLatin1("destinationFolder"));
 
   QTest::newRow("string-11") << "%n to %1"
+                             << "1 copied to destinationFolder"
                              << "1 Datei war nach destinationFolder kopiert"
                              << QString::fromUtf8("1 fichier a été copié à destinationFolder")
                              << QString::fromLatin1("Files have already been copied")
@@ -220,6 +256,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 1 << QString::fromLatin1("destinationFolder"));
 
   QTest::newRow("string-12") << "%n to %1"
+                             << "2 copied to destinationFolder"
                              << "2 Datein wird nach destinationFolder kopiert"
                              << QString::fromUtf8("2 fichiers sont copiés à destinationFolder")
                              << QString::fromLatin1("Files are being copied")
@@ -227,6 +264,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 2 << QString::fromLatin1("destinationFolder"));
 
   QTest::newRow("string-13") << "%n to %1"
+                             << "2 copied to destinationFolder"
                              << "2 Datein war nach destinationFolder kopiert"
                              << QString::fromUtf8("2 fichiers ont été copiés sur destinationFolder")
                              << QString::fromLatin1("Files have already been copied")
@@ -234,6 +272,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << 2 << QString::fromLatin1("destinationFolder"));
 
   QTest::newRow("string-14") << "from %1 to %2"
+                             << "from sourceFolder to destinationFolder"
                              << "nach destinationFolder von sourceFolder"
                              << QString::fromUtf8("à partir de sourceFolder destinationFolder")
                              << QString::fromLatin1("Files are being copied from %1 to %2")
@@ -241,6 +280,7 @@ void TestInternationalization::testStrings_data()
                              << (QVariantList() << QString::fromLatin1("sourceFolder") << QString::fromLatin1("destinationFolder"));
 
   QTest::newRow("string-15") << "%1 messages at %2, fraction of total: %3. Rating : %4"
+                             << "1000 messages at 2005-05-07, fraction of total: 0.6. Rating : 4.8"
                              << "1000 Nachrichten am 2005-05-07, ratio: 0.6. Bemessungen : 4.8"
                              << QString::fromUtf8("1000 messages au 2005-05-07, la fraction du total: 0.6. Note: 4.8")
                              << QString()
@@ -378,6 +418,39 @@ void TestInternationalization::testLocalizedTemplate_data()
                          "Aujourd&#39;hui" " -- 1 000 -- 07/05/05 -- 0,60 -- 4,80 -- 04:05 -- 07/05/05 04:05"
                          "Heute"           " -- 1.000 -- 07.05.05 -- 0,60 -- 4,80 -- 04:05 -- 07.05.05 04:05")
     << dict;
+
+  dict.insert( QLatin1String( "list" ), QVariantList() << 1000);
+  QTest::newRow("fragment-06")
+    << QString::fromLatin1("{{ _(list.0) }}")
+      << QString::fromUtf8( "1,000" )
+      << QString::fromUtf8( "1,000" )
+      << QString::fromUtf8( "1,000" )
+      << QString::fromUtf8( "1.000" )
+      << QString::fromUtf8( "1 000" ) << dict;
+
+  dict.clear();
+  dict.insert(QLatin1String("longlong"), (qlonglong)1000);
+  dict.insert(QLatin1String("float"), (float)0.6);
+  dict.insert(QLatin1String("double"), (float)4.8);
+  dict.insert(QLatin1String("hash"), QVariantHash());
+
+  QTest::newRow("fragment-07")
+    << QString::fromLatin1("{{ _(longlong) }} {{ _(float) }} {{ _(double) }}{{ _(hash) }}")
+    << QString::fromLatin1("1,000 0.60 4.80")
+    << QString::fromLatin1("1,000 0.60 4.80")
+    << QString::fromLatin1("1,000 0.60 4.80")
+    << QString::fromLatin1("1.000 0,60 4,80")
+    << QString::fromUtf8("1 000 0,60 4,80")
+    << dict;
+
+  QTest::newRow("fragment-08")
+    << QString::fromLatin1("{{ 'this'|cut:_(\"i\") }}")
+    << QString::fromLatin1("ths")
+    << QString::fromLatin1("ths")
+    << QString::fromLatin1("ths")
+    << QString::fromLatin1("ths")
+    << QString::fromUtf8("ths")
+    << dict;
 }
 
 void TestInternationalization::testSafeContent()
@@ -732,7 +805,7 @@ void TestInternationalization::testFloats_data()
   QTest::addColumn<QString>("frFloatingPoint");
 
   QTest::newRow("float-01")
-    << 7.4
+    << qreal(7.4)
     << QString::fromLatin1("7.4")
     << QString::fromLatin1("7.40")
     << QString::fromLatin1("7.40")
